==> arm-compute-library_19.11.orig.tar.xz: arm-compute-library-19.11/tests/ILutAccessor.h <==
/*
 * Copyright (c) 2017-2018 ARM Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef __ARM_COMPUTE_TEST_ILUTACCESSOR_H__
#define __ARM_COMPUTE_TEST_ILUTACCESSOR_H__

#include "arm_compute/core/Coordinates.h"
#include "arm_compute/core/Types.h"

namespace arm_compute
{
namespace test
{
/** Common interface to provide information and access to Lut like
 * structures.
 */
template <typename T>
class ILutAccessor
{
public:
    /** Lut value type */
    using value_type = T;

    /** Pure virtual destructor. */
    virtual ~ILutAccessor() = default;

    /** Number of elements of the Lut.
     *
     * @return the number of elements.
     */
    virtual int num_elements() const = 0;

    /** Read access to the specified element.
     *
     * @param[in] input_value Lut input value, from numericlimits<T>:min to numericlimits<T>:max.
     *
     * @return Output desired element.
     */
    virtual const T &operator[](T input_value) const = 0;

    /** Write access to the specified element.
     *
     * @param[in] input_value Lut input value, from numericlimits<T>:min to numericlimits<T>:max.
     *
     * @return Output desired element.
     */
    virtual T &operator[](T input_value) = 0;
};

} // namespace test
} // namespace arm_compute
#endif /* __ARM_COMPUTE_TEST_ILUTACCESSOR_H__ */

==> arm-compute-library_20.08+dfsg.orig.tar.xz: arm-compute-library-20.08+dfsg/tests/ILutAccessor.h <==
/*
 * Copyright (c) 2017-2019 Arm Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef ARM_COMPUTE_TEST_ILUTACCESSOR_H
#define ARM_COMPUTE_TEST_ILUTACCESSOR_H

#include "arm_compute/core/Coordinates.h"
#include "arm_compute/core/Types.h"

namespace arm_compute
{
namespace test
{
/** Common interface to provide information and access to Lut like
 * structures.
 */
template <typename T>
class ILutAccessor
{
public:
    /** Lut value type */
    using value_type = T;

    /** Pure virtual destructor. */
    virtual ~ILutAccessor() = default;

    /** Number of elements of the Lut.
     *
     * @return the number of elements.
     */
    virtual int num_elements() const = 0;

    /** Read access to the specified element.
     *
     * @param[in] input_value Lut input value, from numericlimits<T>:min to numericlimits<T>:max.
     *
     * @return Output desired element.
     */
    virtual const T &operator[](T input_value) const = 0;

    /** Write access to the specified element.
     *
     * @param[in] input_value Lut input value, from numericlimits<T>:min to numericlimits<T>:max.
     *
     * @return Output desired element.
     */
    virtual T &operator[](T input_value) = 0;
};

} // namespace test
} // namespace arm_compute
#endif /* ARM_COMPUTE_TEST_ILUTACCESSOR_H */
